summaryrefslogtreecommitdiff
path: root/gnu/packages/golang-compression.scm
diff options
context:
space:
mode:
authorSharlatan Hellseher <sharlatanus@gmail.com>2026-02-14 19:34:00 +0000
committerAndreas Enge <andreas@enge.fr>2026-02-15 14:17:42 +0100
commit5de19fdadcd89f81f871eb4dedfc05bb7913d96f (patch)
tree9fcd9bba4715e1c1c6355f0292bd4f582e748c39 /gnu/packages/golang-compression.scm
parente9e9e3ac742e79f5e4df48c024c11f7925d64c70 (diff)
gnu: go-github-com-datadog-zstd: Update to 1.5.7.
* gnu/packages/golang-compression.scm (go-github-com-datadog-zstd): Update to 1.5.7. [inputs]: Remove list, zstd, and "lib". [propagated-inputs]: Add pkg-config and (list zstd "lib"). [native-inputs]: Remove pkg-config. Change-Id: I061724fc1278ad4510592f598dd23c7e09afb9be
Diffstat (limited to 'gnu/packages/golang-compression.scm')
-rw-r--r--gnu/packages/golang-compression.scm16
1 files changed, 8 insertions, 8 deletions
diff --git a/gnu/packages/golang-compression.scm b/gnu/packages/golang-compression.scm
index 55e15cab1a7..3c14ad23cfa 100644
--- a/gnu/packages/golang-compression.scm
+++ b/gnu/packages/golang-compression.scm
@@ -159,7 +159,7 @@ to @url{https://pkg.go.dev/io/fs#FS, fs.FS}, but for tar files.")
(define-public go-github-com-datadog-zstd
(package
(name "go-github-com-datadog-zstd")
- (version "1.5.6")
+ (version "1.5.7")
(source
(origin
(method git-fetch)
@@ -168,19 +168,19 @@ to @url{https://pkg.go.dev/io/fs#FS, fs.FS}, but for tar files.")
(commit (string-append "v" version))))
(file-name (git-file-name name version))
(sha256
- (base32 "0hri68jd5yh9kxy4bj2b4rfi7jz74zl20d4hk7rwcwykpgk90qid"))))
+ (base32 "0hm1blyymf1zhgid8f65s2bdd2qz4wiicpnxrv1b18xc8q7fv8hs"))))
(build-system go-build-system)
(arguments
(list
;; These flags need to be applied in the final application as well to
;; build with system's libzstd,
#:build-flags #~(list "-tags" "external_libzstd")
#:test-flags #~(list "-tags" "external_libzstd")
#:import-path "github.com/DataDog/zstd"))
- (native-inputs
- (list pkg-config))
- (inputs
- (list (list zstd "lib")))
+ (propagated-inputs
+ (list pkg-config
+ (list zstd "lib")))
(home-page "https://github.com/DataDog/zstd")
(synopsis "Zstd Golang wrapper")
(description
@@ -168,19 +168,19 @@ to @url{https://pkg.go.dev/io/fs#FS, fs.FS}, but for tar files.")
(arguments
(list
- ;; These flags need to be applied in the final application as well to
- ;; build with system's libzstd,
+ ;; XXX: These flags need to be applied in the final application as well
+ ;; to build with system's libzstd. Keep all inputs as propagated as
+ ;; well.
#:build-flags #~(list "-tags" "external_libzstd")
#:test-flags #~(list "-tags" "external_libzstd")